demono
======

Simple and small Unix daemon library.

License: MIT.


Features
========

* Very simple

Installation
============

From source:

* ``git clone git@gitlab.com:mezozoysky/demono.git``
* ``cd demono``
* ``python3 setup.py install``

Requirements
============

* Python 3

Note: Click 6.x required for running sample daemons only.

Limitations
===========

* Unix only

Getting Help
============
    
* Email me: <s.demyanovich@protonmail.com>
* Post `issues to GitLab <http://gitlab.com/mezozoysky/demono/issues>`

